@@ -95,10 +95,10 @@ def inspect(*arrays, **kwargs):
                 line()
 
         elif hasattr(arr, 'shape'):
-            sh, m, M = arr.shape, arr.min(), arr.max()
+            sh, m, M, dtype = arr.shape, arr.min(), arr.max(), arr.dtype
             try: me = arr.mean()
             except: me = arr.float().mean()
-            print(f'{name}{typ}\tShape: {sh}\tMin: {m:.3f}\tMax: {M:.3f}\tMean: {me:.3f}')
+            print(f'{name}{typ}\tShape: {sh}\tMin: {m:.3f}\tMax: {M:.3f}\tMean: {me:.3f}\tdtype: {dtype}')
             line()
         else:
             ln = len(arr)
@@ -325,3 +325,10 @@ class L(list):
 
 uint = lambda im: (255*im).astype(np.uint8)
 Blank = lambda *sh: uint(np.ones(sh))
+
+'''108 ways to orgasm
+* Walk on soil
+* Drink clean water, eyes closed and sitting
+* When a sneeze comes, breath in instead of out
+* Feel your heart at the moment of sleep
+'''
