@@ -4,7 +4,7 @@
 - [ ] make plot_epochs even faster
 '''
 
-__all__ = ['torch','th','torchvision','T','nn','np','F','Dataset','DataLoader','optim','Report']
+__all__ = ['torch','th','torchvision','T','nn','np','F','Dataset','DataLoader','optim','Report','Reshape','Permute']
 
 import torch, torchvision
 import torch as th
@@ -18,6 +18,19 @@ from collections import namedtuple, defaultdict
 import re
 from itertools import dropwhile, takewhile
 
+class Reshape(nn.Module):
+    def __init__(self, *shape):
+        super().__init__()
+        self.shape = shape
+    def forward(self, x):
+        return x.view(*self.shape)
+class Permute(nn.Module):
+    def __init__(self, *order):
+        super().__init__()
+        self.order = order
+    def forward(self, x):
+        return x.permute(*self.order)
+
 metric = namedtuple('metric', 'pos,val'.split(','))
 info = lambda report: '\t'.join([f'{k}: {v:.3f}' for k,v in report.items()])
 
@@ -89,11 +102,12 @@ class Report:
         plt.legend()
         if _show: plt.show()
 
-    def report_avgs(self, epoch):
+    def report_avgs(self, epoch, return_avgs=False):
         avgs = {}
         for k in self.logged:
             avgs[k] = np.mean([v for pos,v in getattr(self,k) if epoch-1<=pos<epoch])
         self.report_metrics(epoch, **avgs)
+        if return_avgs: return avgs
 
     def report_metrics(self, pos, **report):
         '''Report training and validation metrics
